@@ -23,6 +23,15 @@ test_that("dl_stats19 works for 2017", {
   # already downloaded
   expect_message(dl_stats19(year = "2017"),
                  "Data already exists in data_dir")
+  expect_message(dl_stats19(2017:2018))
+  # should also be true
+  expect_true(dir.exists(file.path(
+    get_data_directory(), "dftRoadSafetyData_Accidents_2017"
+  )))
+  # 2018 comes just as csv's
+  expect_true(file.exists(file.path(
+    get_data_directory(), "dftRoadSafetyData_Accidents_2018.csv"
+  )))
 })
 
 test_that("dl_stats19 works for a type", {
